import com.silanis.esl.sdk.*;
import com.silanis.esl.sdk.builder.CustomFieldBuilder;
import com.silanis.esl.sdk.builder.FieldBuilder;
import com.silanis.esl.sdk.builder.TextAnchorBuilder;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.List;
 
import static com.silanis.esl.sdk.builder.CustomFieldBuilder.customFieldWithId;
import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignatureBuilder.signatureFor;
import static com.silanis.esl.sdk.builder.SignerBuilder.newSignerWithEmail;
import static com.silanis.esl.sdk.builder.TranslationBuilder.newTranslation;

public class customFields {
	
    public static final String email1 = "esl.signer1@example.com";
    public static final String email2 = "esl.signer2@example.com";
    public static final String API_KEY = "your_api_key_here";
    public static final String API_URL = "https://sandbox.e-signlive.com/api";
    
	public static void main(String[] args) throws FileNotFoundException {
		
		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		//PDF to create package
		InputStream fs = new FileInputStream("DOC_FILE_PATH");
		
		// First custom field
        String customFieldId1 = "policy_number_id";
        CustomField customField = CustomFieldBuilder.customFieldWithId(customFieldId1)
        		.withDefaultValue("123-456-789-00000000")
                .withTranslation(newTranslation("en")
                        .withName("Policy Number")
                        .withDescription("Car Insurance Policy Number."))
                .build();
        					
        eslClient.getCustomFieldService().createCustomField(customField);
 
        // Second custom field
        String customFieldId2 = "agent_number_id";
        CustomField customField2 = eslClient.getCustomFieldService()
                .createCustomField(customFieldWithId(customFieldId2)
                                .withDefaultValue("0-987-654-321")
                                .withTranslation(newTranslation("en")
                                        .withName("Agent Number")
                                        .withDescription("Employee Agent Number."))
                                .build()
                );
 
 
        // Create and send package with two custom fields
        DocumentPackage superDuperPackage = newPackageNamed("Sample Insurance policy")
                .withSigner(newSignerWithEmail(email1)
                        .withFirstName("John")
                        .withLastName("Smith")
                        .withCustomId("Signer1"))
                .withSigner(newSignerWithEmail(email2)
                        .withFirstName("Mary")
                        .withLastName("Doe")
                        .withCustomId("Signer2"))
                .withDocument(newDocumentWithName("Sample Contract")
                                .fromStream(fs, DocumentType.PDF)
                                .enableExtraction()
                                .withSignature(signatureFor(email1)
                                        .withPositionAnchor(TextAnchorBuilder.newTextAnchor("Client Signature")
                                        		.atPosition(TextAnchorPosition.TOPLEFT)
                                        		.withOccurence(0)
                                        		.withCharacter(16)
                                        		.withSize(250, 70)
                                        		.withOffset(20, -58))
                                        .withField(FieldBuilder.customField(customField.getId())
                                        		.withPositionAnchor(TextAnchorBuilder.newTextAnchor("Policy Number")
                                                		.atPosition(TextAnchorPosition.TOPLEFT)
                                                		.withOccurence(0)
                                                		.withCharacter(13)
                                                		.withSize(250, 25)
                                                		.withOffset(20, -10))))
                                .withSignature(signatureFor(email2)
                                        .withPositionAnchor(TextAnchorBuilder.newTextAnchor("Manager Signature")
                                        		.atPosition(TextAnchorPosition.TOPLEFT)
                                        		.withOccurence(0)
                                        		.withCharacter(17)
                                        		.withSize(250, 70)
                                        		.withOffset(20, -58))
                                        .withField(FieldBuilder.customField(customField2.getId())
                                        		.atPosition(50, 50)
                                        		.onPage(0)
                                                ))
                )
                .build();
 
        PackageId packageId = eslClient.createPackage(superDuperPackage);

        DocumentPackage retrievedPackage = eslClient.getPackage( packageId );
 
        // Get the entire list of custom field from account
        List<CustomField> retrieveCustomFieldList1 = eslClient.getCustomFieldService().getCustomFields(Direction.ASCENDING);
 
        // Get the first custom field from account
        CustomField retrieveCustomField = eslClient.getCustomFieldService().getCustomField(customFieldId1);
 
        // Delete the second custom field from account
        eslClient.getCustomFieldService().deleteCustomField(customFieldId2);
        
	}

}
